# reflectance
Python package to manipulate reflectance data

Main features
-------------

- **Visualisation of reflectance data**.

- **Queries on data and metadata**.

- **Mathematical operations on reflectance data**: average, interpolation.


Installation or upgrade
-----------------------

To install `reflectance`, use::

     pip install reflectance

To upgrade from an older version, use::

     pip install --upgrade reflectance

Further details are in the `on-line documentation
<https://g-patin.github.io/reflectance/>`_.
